@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-logger
 version: 0.3.18
-id: monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
-key: monad_Id8wcZ1XP4k2MT14VfS4eX
+id: monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
+key: monad_7IcOjMAKk6lFOj05Po10VD
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/kazu-yamamoto/logger
@@ -19,20 +19,20 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
 library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
 data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.18
-hs-libraries: HSmonad-logger-0.3.18-Id8wcZ1XP4k2MT14VfS4eX
+hs-libraries: HSmonad-logger-0.3.18-7IcOjMAKk6lFOj05Po10VD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
+    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     monad-loops-0.4.3-b8dcb4f8d0b758186f0f7001488f9c96
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
     stm-chans-3.0.0.4-b9497ea62b3d0161f6f6b1f5b4ed3526
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
